Method: WordpressClient::Post#status

Defined in:
lib/wordpress_client/post.rb,
lib/wordpress_client/post.rb

#status"publish", ...

Returns the current status of the post, or nil if undetermined.

Returns:

  • ("publish", "future", "draft", "pending", "private", nil)

    the current status of the post, or nil if undetermined



34
35
36
# File 'lib/wordpress_client/post.rb', line 34

def status
  @status
end