Returns the current status of the post, or nil if undetermined.
nil
Returns:
the current status of the post, or nil if undetermined
34 35 36
# File 'lib/wordpress_client/post.rb', line 34 def status @status end